

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","abslog10pvalue","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0002376","immune system process",0.600,1.5509,0.925,0.000,"immune system process"),
c("GO:0003008","system process",0.660,2.9199,0.925,0.000,"system process"),
c("GO:0006606","protein import into nucleus",0.102,3.0653,0.452,0.000,"protein import into nucleus"),
c("GO:0042886","amide transport",0.337,1.8688,0.660,0.689,"protein import into nucleus"),
c("GO:0071702","organic substance transport",4.980,1.6216,0.626,0.407,"protein import into nucleus"),
c("GO:0071705","nitrogen compound transport",1.767,1.7578,0.652,0.262,"protein import into nucleus"),
c("GO:0033365","protein localization to organelle",0.609,1.8688,0.474,0.685,"protein import into nucleus"),
c("GO:0017038","protein import",0.257,2.4454,0.545,0.577,"protein import into nucleus"),
c("GO:0015833","peptide transport",0.298,1.8688,0.616,0.449,"protein import into nucleus"),
c("GO:0033036","macromolecule localization",3.030,1.6216,0.646,0.423,"protein import into nucleus"),
c("GO:0051169","nuclear transport",0.239,2.0379,0.567,0.633,"protein import into nucleus"),
c("GO:0023052","signaling",6.765,1.6216,0.930,0.000,"signaling"),
c("GO:0032501","multicellular organismal process",2.373,1.6216,0.926,0.000,"multicellular organismal process"),
c("GO:0050896","response to stimulus",12.210,1.9978,0.934,0.000,"response to stimulus"),
c("GO:0051186","cofactor metabolic process",3.985,2.0379,0.905,0.000,"cofactor metabolism"),
c("GO:0065007","biological regulation",20.498,1.5685,0.940,0.000,"biological regulation"),
c("GO:1901564","organonitrogen compound metabolic process",17.886,1.5175,0.934,0.028,"organonitrogen compound metabolism"),
c("GO:0007154","cell communication",7.219,1.6216,0.912,0.056,"cell communication"),
c("GO:0007264","small GTPase mediated signal transduction",0.485,1.6258,0.823,0.067,"small GTPase mediated signal transduction"),
c("GO:0007265","Ras protein signal transduction",0.225,1.6722,0.828,0.541,"small GTPase mediated signal transduction"),
c("GO:0007165","signal transduction",6.621,1.6216,0.819,0.625,"small GTPase mediated signal transduction"),
c("GO:0051188","cofactor biosynthetic process",2.763,1.6216,0.905,0.087,"cofactor biosynthesis"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$abslog10pvalue <- as.numeric( as.character(stuff$abslog10pvalue) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "abslog10pvalue",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
