

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","abslog10pvalue","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0005623","cell",53.553,2.6665,0.965,0.000,"cell"),
c("GO:0016020","membrane",61.592,1.8686,0.971,0.000,"membrane"),
c("GO:0043226","organelle",20.788,2.0465,0.940,0.000,"organelle"),
c("GO:0098796","membrane protein complex",2.473,1.4469,0.892,0.000,"membrane protein complex"),
c("GO:0031224","intrinsic component of membrane",55.975,2.0465,0.883,0.407,"membrane protein complex"),
c("GO:0016021","integral component of membrane",55.868,2.0465,0.883,0.110,"membrane protein complex"),
c("GO:0044425","membrane part",57.394,2.0465,0.892,0.327,"membrane protein complex"),
c("GO:0098827","endoplasmic reticulum subcompartment",0.011,1.9728,0.604,0.000,"endoplasmic reticulum subcompartment"),
c("GO:0031984","organelle subcompartment",0.269,1.7597,0.619,0.292,"endoplasmic reticulum subcompartment"),
c("GO:0043232","intracellular non-membrane-bounded organelle",7.946,1.3230,0.512,0.677,"endoplasmic reticulum subcompartment"),
c("GO:0005856","cytoskeleton",1.542,1.3230,0.589,0.194,"endoplasmic reticulum subcompartment"),
c("GO:0005789","endoplasmic reticulum membrane",0.761,1.9728,0.466,0.681,"endoplasmic reticulum subcompartment"),
c("GO:0012505","endomembrane system",2.811,1.3230,0.807,0.048,"endomembrane system"),
c("GO:0044464","cell part",52.385,2.6665,0.743,0.138,"endomembrane system"),
c("GO:0071944","cell periphery",11.583,1.8251,0.777,0.207,"endomembrane system"),
c("GO:0005622","intracellular",41.175,2.0465,0.740,0.378,"endomembrane system"),
c("GO:0043228","non-membrane-bounded organelle",8.408,1.3230,0.617,0.609,"endomembrane system"),
c("GO:0005737","cytoplasm",26.017,2.0465,0.648,0.439,"endomembrane system"),
c("GO:0043231","intracellular membrane-bounded organelle",13.760,1.8429,0.459,0.692,"endomembrane system"),
c("GO:0044424","intracellular part",35.654,2.0465,0.671,0.346,"endomembrane system"),
c("GO:0043229","intracellular organelle",19.917,2.0465,0.475,0.448,"endomembrane system"),
c("GO:0005886","plasma membrane",10.510,1.8608,0.749,0.200,"endomembrane system"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$abslog10pvalue <- as.numeric( as.character(stuff$abslog10pvalue) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "abslog10pvalue",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
